@@ -3,7 +3,10 @@ from .base_types import (
     UnifiedTraderInfo,
     UnifiedTraderPositions,
     UnifiedPositionInfo,
+    UnifiedFuturesMarketInfo,
+    UnifiedSingleFutureMarketInfo,
 )
+from .binance import BinanceClient
 from .blofin import BlofinClient
 from .bx_ultra import BXUltraClient
 from .hyperliquid import HyperLiquidClient
@@ -12,11 +15,14 @@ from .okx import OkxClient
 
 __all__ = [
     "ExchangeBase",
-    "UnifiedTraderInfo",
-    "UnifiedTraderPositions",
-    "UnifiedPositionInfo",
     "BXUltraClient",
+    "BinanceClient",
     "BlofinClient",
     "HyperLiquidClient",
     "OkxClient",
+    "UnifiedTraderInfo",
+    "UnifiedTraderPositions",
+    "UnifiedPositionInfo",
+    "UnifiedFuturesMarketInfo",
+    "UnifiedSingleFutureMarketInfo",
 ]
