@@ -52,6 +52,7 @@ from trd_utils.cipher import AESCipher
 from trd_utils.exchanges.errors import ExchangeError
 from trd_utils.exchanges.exchange_base import ExchangeBase, JWTManager
 from trd_utils.exchanges.price_fetcher import IPriceFetcher
+from trd_utils.types_helper import new_list
 
 PLATFORM_ID_ANDROID = "10"
 PLATFORM_ID_WEB = "30"
@@ -77,8 +78,6 @@ logger = logging.getLogger(__name__)
 # specific to the current session that is fetching them,
 user_api_identity_cache: dict[int, int] = {}
 
-__positions_hidden_warn_map: dict[str, bool] = {}
-
 
 class BXUltraClient(ExchangeBase, IPriceFetcher):
     ###########################################################
@@ -921,11 +920,10 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
         self,
         uid: int | str,
         api_identity: int | str | None = None,
-        no_warn: bool = False,
         min_margin: Decimal = 0,
     ) -> UnifiedTraderPositions:
-        perp_positions = []
-        std_positions = []
+        perp_positions = new_list()
+        std_positions = new_list()
         perp_ex: str = None
         std_ex: str = None
 
@@ -940,13 +938,6 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
             err_str = f"{ex}"
             if err_str.find("as the client has been closed") != -1:
                 raise ex
-
-            if not no_warn:
-                if err_str.find("positions hidden") != -1:
-                    warn_key = f"perp_{uid}"
-                    if not __positions_hidden_warn_map.get(warn_key, False):
-                        __positions_hidden_warn_map[warn_key] = True
-                    logger.warning(f"Failed to fetch perp positions of {uid}: {ex}")
             perp_ex = ex
 
         try:
@@ -959,13 +950,6 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
             err_str = f"{ex}"
             if err_str.find("as the client has been closed") != -1:
                 raise ex
-
-            if not no_warn:
-                if err_str.find("positions hidden") != -1:
-                    warn_key = f"std_{uid}"
-                    if not __positions_hidden_warn_map.get(warn_key, False):
-                        __positions_hidden_warn_map[warn_key] = True
-                        logger.warning(f"Failed to fetch std positions of {uid}: {ex}")
             std_ex = ex
 
         if not perp_positions and not std_positions:
@@ -1010,7 +994,7 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
             # TODO: do proper exceptions here...
             raise ValueError("The trader has made their positions hidden")
         unified_result = UnifiedTraderPositions()
-        unified_result.positions = []
+        unified_result.positions = new_list()
         for position in result.data.positions:
             if min_margin and (not position.margin or position.margin < min_margin):
                 continue
@@ -1049,7 +1033,7 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
         min_margin: Decimal = 0,
     ) -> UnifiedTraderPositions:
         unified_result = UnifiedTraderPositions()
-        unified_result.positions = []
+        unified_result.positions = new_list()
         current_page_id = page_offset - 1
 
         while True:
