@@ -1,11 +1,12 @@
 
 from .ultra_list import UltraList
-from .base_model import BaseModel
+from .base_model import BaseModel, new_list
 from .decorators import ignore_json_fields
 
 
 __all__ = [
     "UltraList",
     "BaseModel",
+    "new_list",
     "ignore_json_fields",
 ]
